e_antic: Real embedded number fields
====================================

Description
-----------

e-antic is a C library for exact computations with real embedded number
field maintained by Vincent Delecroix.

Website: https://github.com/videlec/e-antic

License
-------

e-antic is licensed GPL v3.


Upstream Contact
----------------

-  https://github.com/videlec/e-antic
